@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0700';
 
 use Moo;
 use Music::Chord::Note;
@@ -68,6 +68,18 @@ sub cadence {
         push @$cadence, $chord;
 
         $chord = $self->_generate_chord( $args{scale}, $scale[0], $args{octave}, $mtr, $mcn );
+        my $top = $chord->[0];
+        if ( $self->format eq 'midinum' ) {
+            $top += 12;
+        }
+        else {
+            if ( $top =~ /^(.+?)(\d+)$/ ) {
+                my $note   = $1;
+                my $degree = $2;
+                $top = $note . ++$degree;
+            }
+        }
+        push @$chord, $top;
         push @$cadence, $chord;
     }
     elsif ( $args{type} eq 'plagal' ) {
@@ -158,7 +170,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0601
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -167,12 +179,12 @@ version 0.0601
   my $mc = Music::Cadence->new;
 
   my $chords = $mc->cadence( type => 'perfect' );
-  # [['G','B','D'], ['C','E','G']]
+  # [['G','B','D'], ['C','E','G','C']]
 
   $mc = Music::Cadence->new( octave => 4 );
 
   $chords = $mc->cadence( type => 'perfect' );
-  # [['G4','B4','D4'], ['C4','E4','G4']]
+  # [['G4','B4','D4'], ['C4','E4','G4','C5']]
 
   $chords = $mc->cadence(
     type    => 'half',
@@ -186,7 +198,7 @@ version 0.0601
   );
 
   $chords = $mc->cadence( type => 'perfect' );
-  # [['G#5','C5','D#5'], ['C#5','F5','G#5']]
+  # [['G#5','C5','D#5'], ['C#5','F5','G#5','C#6']]
 
   $mc = Music::Cadence->new(
     key    => 'C#',
@@ -195,7 +207,7 @@ version 0.0601
   );
 
   $chords = $mc->cadence( type => 'perfect' );
-  # [['Gs5','C5','Ds5'], ['Cs5','F5','Gs5']]
+  # [['Gs5','C5','Ds5'], ['Cs5','F5','Gs5','Cs6']]
 
   $mc = Music::Cadence->new(
     key    => 'C',
@@ -204,7 +216,7 @@ version 0.0601
   );
 
   $chords = $mc->cadence( type => 'perfect' );
-  # [[67,71,62], [60,64,67]]
+  # [[67,71,62], [60,64,67,72]]
 
 =head1 DESCRIPTION
 
@@ -288,9 +300,6 @@ Create a new C<Music::Cadence> object.
 Return an array reference of the chords of the cadence B<type> based
 on the given B<key> and B<scale> name.
 
-The B<octave> is optional and if given, should be a number greater
-than or equal to zero.
-
 The B<variation> applies to the C<deceptive> cadence and determines
 the final chord.  If given as C<1>, the C<vi> chord is used.  If given
 as C<2>, the C<IV> chord is used.
